@@ -4,6 +4,4 @@ Put project's custom urls in this file
 from django.conf.urls import *
 
 
-urlpatterns = patterns('',
-
-)
+urlpatterns = patterns('',)
